/*
 * Copyright (C) 2010 Jacob Kjome
 * 
 * This file is part of XMLC.
 *
 * XMLC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1
 * of the License, or (at your option) any later version.
 *
 * XMLC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with XMLC.  If not,
 * see <http://www.gnu.org/licenses/>.
 */
package xmlc.demo;

import org.w3c.dom.Node;
import org.w3c.dom.traversal.NodeFilter;

/**
 * Provides for applying multiple NodeFilters in a single node traversal.  Skips
 * nodes by default.  If at least one of the NodeFilters reports acceptance of a
 * node the node will be accepted.
 */
public final class CompoundNodeFilter implements NodeFilter {
    private final NodeFilter[] nodeFilters;

    /**
     * @param nodeFilters the node filters, may be null or empty in which case
     *                    all nodes will be skipped
     */
    public CompoundNodeFilter(final NodeFilter[] nodeFilters) {
        this.nodeFilters = nodeFilters;
    }

    public short acceptNode(final Node n) {
        short retVal = NodeFilter.FILTER_SKIP;
        if (nodeFilters == null) return retVal;
        for (int i = 0; i < nodeFilters.length; i++) {
            final NodeFilter nodeFilter = (NodeFilter) nodeFilters[i];
            if (nodeFilter.acceptNode(n) == NodeFilter.FILTER_ACCEPT) {
                retVal = NodeFilter.FILTER_ACCEPT;
            }
        }
        return retVal;
    }

}
