/*
 * Copyright (C) 2010 Jacob Kjome
 * 
 * This file is part of XMLC.
 *
 * XMLC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1
 * of the License, or (at your option) any later version.
 *
 * XMLC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with XMLC.  If not,
 * see <http://www.gnu.org/licenses/>.
 */
package xmlc.demo;

import java.util.Iterator;
import java.util.Set;

import org.w3c.dom.Attr;

/**
 * Qualifies URI path attributes when paths are found to be unqualified.  Skips
 * attributes with paths that are already qualified.  Must iterate to apply
 * changes.  Don't forget to detach to release resources!
 * <p>
 * Path related attributes include "href", "src", "longdesc", "background",
 * "cite", "action", and "codebase".  Attribute values are only modified if
 * their paths are unqualified.  Fully qualified paths (those starting with
 * "/" or containing a protocol, such as "http:") are left untouched and
 * skipped by this filter.
 * </p>
 */
public class PathQualifierNodeFilter extends AbstractPathModifierNodeFilter {
    private final String pathPrefix;

    /**
     * @param pathPrefix the prefix to add to a relevant link's path,
     *                   including any slashes required
     */
    public PathQualifierNodeFilter(final String pathPrefix) {
        this.pathPrefix = pathPrefix;
    }

    protected boolean didModifyPathAttr(final Set/*<Attr>*/ pathAttrs) {
        boolean retVal = false;
        for (final Iterator/*<Attr>*/ iter = pathAttrs.iterator(); iter.hasNext();) {
            final Attr pathAttr = (Attr) iter.next();
            final String path = pathAttr.getValue().trim();
            if (!isFullQualifiedPath(path)) {
                pathAttr.setValue(pathPrefix + path);
                retVal = true;
            }
        }
        return retVal;
    }

}
